/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvMath.h"
#include "HvControlCast.h"
#include "HvSignalLine.h"
#include "HvControlBinop.h"
#include "HvControlDelay.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvSignalVar.h"
#include "HvSignalEnvelope.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_BQ9Mp3Q1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b7fDYoGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iY5sHbqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Iw7db3zL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wba9tFos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GIoeNHtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EnJsLVmh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d3PRJP5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D8PT3wDL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_snxLrw99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0TTAHzO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ISN2z9Ec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KndcCB0t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_za2n6tOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vyf6Eq3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TYfdimWi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YdfZQrKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LxWcItng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_meNqCyNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1dB2M1Uh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ynKPTEfd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_30wxPjYo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_bG0EI83V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1fwXsqEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lXVBeZTz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Hg1mhXQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6E3walg8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ebAC5gH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_L1W1HIkn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9Z1Q1Wii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XteFqGUZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_BnBEIwKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_das30vHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_koGMKYCb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wxcmIhEB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k8ExTauo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VJ5NDBYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X9NE5ZSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zibbf2U6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t1EiQoQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NJWaqMBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tfaTk5Gk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rNQr4Tm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Zq2h1jPX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zQiyN4LD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_xlVYsvbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_doWl4wSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Milj0Q6t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tFbEfCzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IyGxCKGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KHJE9l3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cw18xqcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V74sP8R4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jOLoS7Yz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KPxnExxP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZCM7Hsxz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jryqNZWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YmXCHIKn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cP3JJCb0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_GhLrcN0k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9yarkxPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AAEz7qxA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8JEfRaIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YLg7ZOkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tqpg3H31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qC9ERzu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AcL4UEVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RtE01Bjt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ubXprlan_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xEOjKx0z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wCrn1owZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0Jb4ISk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aI3YVGcT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_GGeZB9GN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vHjnQM4w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ph4ReyYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6X6pgnaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mvcfcfcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IS6YaCNZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6AErzyqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gco9yJdp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gA8LJ088_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VQHS4mNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6TvEZO6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_np18q6SB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2DyycHxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ykHSt40A_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_C5aMll6G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3QO3jEXw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8nlE14XK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d6XnGYI3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3RAx0162_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C6njOpvA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jqb4PMsJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HzmdNz5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jqBVCzVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tBtv7U99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mphNs2i1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2jOBTrzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_eDdfurrZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sIU8jLoE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_t5JOlWnI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YHrBZUzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cLIG6uIa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_frTn16tg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t51vyR7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JSjlkuCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XCTsw4Z3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kv8Gjte0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OXPE527G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xZCT8iIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XRffICZJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9G3fAkn5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3bKPLbMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kVJ2OTzp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_dX8n64Gd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LYW7upkU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WZ65inDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3yu3J6Qa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6CkvPSHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QVQD2Zse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xGPnRtVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UQCCnO7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c2Lt7Bh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k79Scme5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ul3rliRA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rWB56RDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_opL72OfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4X6QdL6L_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_eWqtnhrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zNmdVWEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mHpQ5RYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m3Kqbj8F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_syVSZcU8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V3TnptrY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XOQdUWD7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cNg97iDK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pRIUgmy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XjHrk2ZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NFdi7nZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uOPOf2bD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ycBWc2qm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kVzmAVMS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_J6VRRRNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J36TE5dv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4h4gmmNA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A40XFMHv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1PNXClK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yy6kwUVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x7ZVwglr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pz3scgqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MPaxouJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EesNzJf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QkdzoW3P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VeGiMaM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nIksdIQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xSKkdSVk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_JcCaxluq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lbC5zVzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MMqwDKIA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wCrDKngs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q9BSceO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EiCVyWDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H7UM82OF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UoIGaKz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ryGn2Gy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4voiavrm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BEOgeamm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LvA8T3QR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AjRYG946_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1akykEIJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_YujwppGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q4uC7iXB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W3BYZdzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7VToRYEy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Fqg6Sb6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W5Hb96uy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NN5jiMFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6vfYVuxd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2hU6bfpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IMemNcDK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8dOBuLuz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZQG8wWDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mBUIiSrr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9FCunVSE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_pbnEX3x5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8wr0GLgj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bhGsuCnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WlYZSy6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FDV760Ah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zfcoWsrB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gdey9x68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wnkoQciv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MsSQrqJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TatA7czK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lGNI43pn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l1PvopPk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qd7IOjzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QBIQj8Br_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hWKWPH3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6iXJBlHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AbQRFJgH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O6xphXzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K8u8oRGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EqIlKAvR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0LSIHdgr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qgkV9W2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vp52g28y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P3GxIgbO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bR5XxcrN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D5SIQfmz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G7e3tBPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gr5efCbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6ajpZzeH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m51NEBlJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pu10tOAg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WZzOY4wj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rLkTtR1A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zCKdoCiP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iDn87IGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AwGRCqke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bKdQNbnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T24uUdzn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9fjboZtG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bAOeW2kA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zaAdz5sa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V7sjaPFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ji5oGUUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p4R4zQOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ki8iBhC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7MfP46Z6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r7FBloxG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u5zriyNg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z1it9OJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2wQlhwSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qFGQKCXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VLyIFfcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iRS8ZsEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HXICvz8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_61uPTzYX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kdpTA1D1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ByiYBOB6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vJFNSN8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RR3ZZy28_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_65tdMkY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_x3Ag1FCQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_nKKGbals_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iraNY5GX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BNYNus8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_a14ailup_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_l512Wwio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yNrXpt6w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jK6UscrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JzpC7g9w_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_69cBaYXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NgdKis1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9Qx4c4AK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VyohtFBk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_tXel4qsa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vshwG1zO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hbdPHI2l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zS7CLcQ3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_FqAGncs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vdv4Zlri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6UfI5G0V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_saZ4nJkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Tvp7IF1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tWHoKL2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_VLW2yjeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_GBxkNI7z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eou5zVtH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oE5fxAep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3Dr6ea5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l5pT8I8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hHyBn6gM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4KG98BV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_61qBF6gb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rntNrAXz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I4Xg4wuc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EyK9t4fU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IqXoiu5Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ume4A8rt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0cPyTcXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wRBwx4co_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_e2BP78vE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qQj9RAzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ye3b6iq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6qSWikvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0rKNRsAz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nvfyTidR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tViSv23T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KcEvydpn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NNHWLFUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NrPA5zsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vG6O8jAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZJSMTNZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EJCa6eMR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vgQLCFMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EIbY1376_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VQv5cgWJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MeOAr7MB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_CkiCuxw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aKxXr1YN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wBbrLtbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3uVXZ5lz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_voOhxTRQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RcfPCYWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wb39iFpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DhhR9qZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_I1PYm15N_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_jrPgIHW7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RymeRidQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zwVqDIj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H9GVn63J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0eRf8EsT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kzpTH9JH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KWswbSMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PX0AjT4D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qDeJE0zc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GfbNS5Iu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r0Nxadgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uUSZ8SKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_e0TVT8l1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5d6Qv7UX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_5IkoBbA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_THsdfjia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u4r6hDV0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ehy2E1Aa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sp8cD0BX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m3Bp2H0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2SQFBxJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ObEtvl9l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9GShbqhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SdxOQwkZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lfuwj8nW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rC4Exh6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0TFKN7mx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vHZgXJID_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_xfBPSyPb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ydLPOpyn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KjsVtGBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_soazeXSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QtexksGL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xdkK5Tdg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ooq4VnVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cut49wx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VGDoQbwO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yxJgZdbA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0ybpNlR7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SEs6ywFS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4n7ppdrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ltR5M8uu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_adfLdnFv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XE0GElB5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rOCZUVe4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gfUyxw9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3S5P8rhF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sCFLpN9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y61yTRAA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O0DCBIFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sxdYFKEX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BrwF20Jd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KZO9VTAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_y0JkhkUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XfBpUxvv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LV0nN1dA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_WFzSeEIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a1wasEN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6osl0GNO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JetsNtAV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O3rZpbyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qNuatrcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VDrdoCLB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_powDUnfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_41hUmRD9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FPRnovLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xg0xuimZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tUqc75fK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zSF4DeZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Joaim9x4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_M6K713bn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9llw5lCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7j2MPVQs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zaCTizaz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PXWQt9PW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t9mhyyZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vXSBmWQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DrLbT2Ya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TnbbNsmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zRbXvUTo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ts1s9bX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vasdwuJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oiq5ovHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aglppde2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_lBuGMVfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0FDaX6SI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZJPZ8IJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qon4HxMF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KTlzwlJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mzbAWv57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Sp5phP1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WR4KS1N7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mntFbJOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UxOcDBWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uh4O8d3E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QwY2o8mb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_h9BrmQeE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dNTWEO0t_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_tkN4aXDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6w4PSx3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DpC6eEfN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m5113r6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AEmvqm7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CVs95pJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YYrSeYwT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gsvn2Sf4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6oNqAHfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yPDB7vfI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NOfqOl8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_T8cTApVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qotcEqm4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5rPZaUu2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_3ahiF50B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tVJCoShB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TxAd3FVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SHHgUMko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_davvgcb9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6tRSE1RO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QE9KjsHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I5s8edc0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MqJXHzEQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ijrLoqwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NURSajxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jPsSPHHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BoPAi84o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cDbV7S5U_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_chWp4rfO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_58P61aA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FmnEKyeZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Nf0UGge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gzhNJHzs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SkhOuB5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cJGbHmud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vyqQc1K9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tAUhEjt3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s0NYattH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0oBckRqQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6MSA6DWE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nbnE3t6w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OI2ZF21T_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_jHM8VjWf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jIByQ6iW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2xcK9y3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NfTxT58y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C2gUMnHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iMM1P7aL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yd42e4ET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CDsByVHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pIJ91Ksp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bkLt4uDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nMydzlP3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hAR3aBdN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A93jpCxy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WEuLOU0g_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_a58R7vAF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FMA2eQxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MG8G5EuC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1NZiQT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gyXFQyFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KpLILilb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lz8UMpCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KTbMwJwp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_91hdRuhG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PoL91E0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QUmjtPPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qhhiVdax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_38XfqOlA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xDvrBDua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cTF6jGFM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DVuIOeZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2qiprC89_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bnYCAnqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IvnykIGA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wNVBaly8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yvjgX9zU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3aYUKF5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0vAivVcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BTEXBo5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zQ5uCHWR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lYPObPyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_siJp3Mis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HNJBGxgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oWVWS5Hp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2inZhHar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YVN5u1gM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_socKUISw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D5bR187N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4UU7jYBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vMRzPvUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G9nBoSqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UC0TTOuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WPkldtPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z9ftDMLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rOl1kLGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P25oa0St_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WLql5oEr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CXW6FQ04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zjSNaRxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FWNu62Tl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dqnqkS89_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jxQ5Q90u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TRspgEyc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O9lwqIz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qOsJUUmQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OiyfP5M3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CVBwMEig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eJCGDGVa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DG3e5ENZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lSlXRy2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o5ECzs93_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BfazAu2M_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_eF5KBtNr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wgxqY0Oi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_usxU1iZf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ch1TWavf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_KbXNHaAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qjfYXgBt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dQUGo1Fy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kplz3XFQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5Uh47AzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EWJ64dCM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PypTcEIA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qflEAIa8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_V79YuEvs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_whtEv2f4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TzScySUq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TVXyOI8M_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4Y5R3uop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LmS6HJtL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Lzaq7oUv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ufNJ0wIT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_n46i99q5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eZVWrszd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kJazMotx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6XxrHDIZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tIlzGX36_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Cm4tABHl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_QG5mvrzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_mQMk3SNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N6h8Kbai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JkWGsCWK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LUeGlAKB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MjTezGix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bUTuwEwp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NGakSjXE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lDScZvR0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aRGGNmSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qh9EA6PB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vi6ShwNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tvdlFRr6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yBIi932S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8BsD6MAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aIUt2v96_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_o2KGk3Cv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ji84dnK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pVbSWgqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RU2VjeTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bNLH8lkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BNhtZVhb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lmj7par9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o0hVVu2U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ehC08mEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ds6ov9r1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GtMeQMKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IaRxUE2K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gWEr9QT0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S0nRTQA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0AQXxosv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VcxU24Dm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zkXDLi8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_L24Ils5f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ozptETRh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7vspuxi9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vkvbfDMi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1HKYOX1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ycC3H3d9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lXSOxSC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8L3UQGwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JFwReyyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nALJqmjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i3naFO1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kms1xO7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XxsHUCpP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_imFruMzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VAkYco5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R3lF334e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TpluaabN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Qz9ONBAg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_76LbTzAk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P9kdSzWJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eZYkjVQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NNyPxXLy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_U5AgkAej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rFFhUGX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_x3jgsdOf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Z4Y61TKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8ctiBTYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2E6pJqwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RR5NhbUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YvR4A3K8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3RqNkJmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hceLZNPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AI4GO4ps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Zlk2IyTd_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_zeeqNJPT;
  SignalLine sLine_GnUEgPVV;
  SignalLine sLine_QJ933Gfb;
  SignalLine sLine_MiMYezHw;
  SignalLine sLine_nmhDBwHH;
  SignalLine sLine_4LRIWGRj;
  SignalLine sLine_NcLEsPMp;
  SignalLine sLine_hXpgz07j;
  SignalLine sLine_sFgwHGbm;
  SignalLine sLine_RTelv2dT;
  SignalLine sLine_VCQD0ZuR;
  SignalLine sLine_UuhYPyoC;
  SignalEnvelope sEnv_VLW2yjeq;
  SignalEnvelope sEnv_GBxkNI7z;
  SignalLine sLine_Y6Mk3UKB;
  SignalLine sLine_8GWuojOz;
  SignalLine sLine_gQYA2KRZ;
  SignalLine sLine_By1HqzXr;
  SignalLine sLine_GFCNc8Om;
  SignalLine sLine_ymDErHOy;
  SignalLine sLine_3vKVOhdl;
  SignalLine sLine_e6yjT1tL;
  SignalLine sLine_Wq1zFKvK;
  SignalLine sLine_vq2svqac;
  SignalLine sLine_sJEu12YS;
  SignalLine sLine_85SDR9B0;
  SignalLine sLine_cl2XeX2q;
  SignalLine sLine_mwTFGVsE;
  SignalLine sLine_FYWjs0Rl;
  SignalLine sLine_K5J18qLv;
  SignalLine sLine_yv9GGVQq;
  SignalLine sLine_DorU08PQ;
  SignalEnvelope sEnv_QG5mvrzE;
  SignalEnvelope sEnv_mQMk3SNJ;
  SignalLine sLine_BBIR43x5;
  SignalLine sLine_5eQi4M1k;
  SignalLine sLine_GqVG9D41;
  SignalLine sLine_sTS0py63;
  SignalLine sLine_aN5qreTy;
  SignalLine sLine_GoZbNMJ9;
  SignalLine sLine_jb3jgnAG;
  SignalLine sLine_WoxHOfkR;
  ControlVar cVar_BQ9Mp3Q1;
  ControlBinop cBinop_b7fDYoGM;
  ControlBinop cBinop_iY5sHbqz;
  ControlBinop cBinop_Iw7db3zL;
  ControlBinop cBinop_wba9tFos;
  ControlBinop cBinop_d3PRJP5U;
  ControlBinop cBinop_snxLrw99;
  ControlBinop cBinop_0TTAHzO9;
  ControlBinop cBinop_ISN2z9Ec;
  ControlVar cVar_KndcCB0t;
  ControlVar cVar_za2n6tOw;
  ControlVar cVar_vyf6Eq3V;
  ControlVar cVar_TYfdimWi;
  ControlVar cVar_YdfZQrKO;
  ControlBinop cBinop_LxWcItng;
  ControlVar cVar_1dB2M1Uh;
  ControlVar cVar_ynKPTEfd;
  ControlIf cIf_L1W1HIkn;
  ControlIf cIf_9Z1Q1Wii;
  ControlDelay cDelay_BnBEIwKF;
  ControlBinop cBinop_wxcmIhEB;
  ControlBinop cBinop_k8ExTauo;
  ControlIf cIf_rNQr4Tm7;
  ControlIf cIf_Zq2h1jPX;
  ControlDelay cDelay_xlVYsvbx;
  ControlBinop cBinop_tFbEfCzG;
  ControlBinop cBinop_IyGxCKGz;
  ControlIf cIf_jryqNZWu;
  ControlIf cIf_YmXCHIKn;
  ControlDelay cDelay_GhLrcN0k;
  ControlBinop cBinop_8JEfRaIX;
  ControlBinop cBinop_YLg7ZOkg;
  ControlIf cIf_wCrn1owZ;
  ControlIf cIf_0Jb4ISk8;
  ControlDelay cDelay_GGeZB9GN;
  ControlBinop cBinop_6X6pgnaG;
  ControlBinop cBinop_mvcfcfcG;
  ControlIf cIf_np18q6SB;
  ControlIf cIf_2DyycHxO;
  ControlDelay cDelay_C5aMll6G;
  ControlBinop cBinop_d6XnGYI3;
  ControlBinop cBinop_3RAx0162;
  ControlIf cIf_2jOBTrzH;
  ControlIf cIf_eDdfurrZ;
  ControlDelay cDelay_t5JOlWnI;
  ControlBinop cBinop_frTn16tg;
  ControlBinop cBinop_t51vyR7G;
  ControlIf cIf_9G3fAkn5;
  ControlIf cIf_3bKPLbMS;
  ControlDelay cDelay_dX8n64Gd;
  ControlBinop cBinop_3yu3J6Qa;
  ControlBinop cBinop_6CkvPSHd;
  ControlIf cIf_rWB56RDO;
  ControlIf cIf_opL72OfH;
  ControlDelay cDelay_eWqtnhrH;
  ControlBinop cBinop_m3Kqbj8F;
  ControlBinop cBinop_syVSZcU8;
  ControlIf cIf_uOPOf2bD;
  ControlIf cIf_ycBWc2qm;
  ControlDelay cDelay_J6VRRRNa;
  ControlBinop cBinop_A40XFMHv;
  ControlBinop cBinop_n1PNXClK;
  ControlIf cIf_VeGiMaM7;
  ControlIf cIf_nIksdIQH;
  ControlDelay cDelay_JcCaxluq;
  ControlBinop cBinop_wCrDKngs;
  ControlBinop cBinop_Q9BSceO5;
  ControlIf cIf_LvA8T3QR;
  ControlIf cIf_AjRYG946;
  ControlDelay cDelay_YujwppGH;
  ControlBinop cBinop_7VToRYEy;
  ControlBinop cBinop_0Fqg6Sb6;
  ControlIf cIf_ZQG8wWDf;
  ControlIf cIf_mBUIiSrr;
  ControlDelay cDelay_pbnEX3x5;
  ControlBinop cBinop_WlYZSy6u;
  ControlBinop cBinop_FDV760Ah;
  SignalVarf sVarf_SSgZtIWg;
  SignalVarf sVarf_GDhJSDgA;
  SignalVarf sVarf_aIMpox5S;
  SignalVarf sVarf_2T3Ua5Zw;
  SignalVarf sVarf_WuABKvPf;
  SignalVarf sVarf_fX9qyFrD;
  SignalVarf sVarf_0NT2wX46;
  SignalVarf sVarf_hovVEQrb;
  ControlVar cVar_kdpTA1D1;
  ControlSlice cSlice_vJFNSN8y;
  ControlVar cVar_RR3ZZy28;
  ControlSlice cSlice_nKKGbals;
  ControlVar cVar_iraNY5GX;
  ControlSlice cSlice_l512Wwio;
  ControlVar cVar_yNrXpt6w;
  ControlSlice cSlice_69cBaYXd;
  ControlVar cVar_NgdKis1Y;
  ControlSlice cSlice_tXel4qsa;
  ControlVar cVar_vshwG1zO;
  ControlDelay cDelay_FqAGncs6;
  ControlVar cVar_saZ4nJkP;
  ControlIf cIf_Tvp7IF1E;
  ControlIf cIf_tWHoKL2R;
  ControlBinop cBinop_Eou5zVtH;
  ControlBinop cBinop_3Dr6ea5q;
  ControlBinop cBinop_l5pT8I8K;
  ControlBinop cBinop_61qBF6gb;
  ControlBinop cBinop_I4Xg4wuc;
  ControlSlice cSlice_e2BP78vE;
  ControlVar cVar_qQj9RAzh;
  SignalVarf sVarf_KckxTEJn;
  SignalVarf sVarf_7uUGcLP5;
  SignalVarf sVarf_2dfvGF0a;
  SignalVarf sVarf_hnOOs6rQ;
  SignalVarf sVarf_CM0EtZcw;
  SignalVarf sVarf_mZWCLdY9;
  ControlBinop cBinop_nvfyTidR;
  ControlBinop cBinop_EJCa6eMR;
  ControlVar cVar_EIbY1376;
  ControlVar cVar_VQv5cgWJ;
  ControlIf cIf_wb39iFpN;
  ControlIf cIf_DhhR9qZC;
  ControlDelay cDelay_jrPgIHW7;
  ControlBinop cBinop_H9GVn63J;
  ControlBinop cBinop_0eRf8EsT;
  ControlIf cIf_uUSZ8SKE;
  ControlIf cIf_e0TVT8l1;
  ControlDelay cDelay_5IkoBbA6;
  ControlBinop cBinop_ehy2E1Aa;
  ControlBinop cBinop_Sp8cD0BX;
  ControlIf cIf_rC4Exh6u;
  ControlIf cIf_0TFKN7mx;
  ControlDelay cDelay_xfBPSyPb;
  ControlBinop cBinop_soazeXSP;
  ControlBinop cBinop_QtexksGL;
  ControlIf cIf_SEs6ywFS;
  ControlIf cIf_4n7ppdrh;
  ControlDelay cDelay_adfLdnFv;
  ControlBinop cBinop_gfUyxw9O;
  ControlBinop cBinop_3S5P8rhF;
  ControlIf cIf_y0JkhkUp;
  ControlIf cIf_XfBpUxvv;
  ControlDelay cDelay_WFzSeEIN;
  ControlBinop cBinop_JetsNtAV;
  ControlBinop cBinop_O3rZpbyu;
  ControlIf cIf_tUqc75fK;
  ControlIf cIf_zSF4DeZM;
  ControlDelay cDelay_M6K713bn;
  ControlBinop cBinop_zaCTizaz;
  ControlBinop cBinop_PXWQt9PW;
  ControlIf cIf_vasdwuJi;
  ControlIf cIf_oiq5ovHe;
  ControlDelay cDelay_lBuGMVfc;
  ControlBinop cBinop_qon4HxMF;
  ControlBinop cBinop_KTlzwlJX;
  ControlIf cIf_QwY2o8mb;
  ControlIf cIf_h9BrmQeE;
  ControlDelay cDelay_tkN4aXDp;
  ControlBinop cBinop_m5113r6h;
  ControlBinop cBinop_AEmvqm7y;
  ControlIf cIf_T8cTApVQ;
  ControlIf cIf_qotcEqm4;
  ControlDelay cDelay_3ahiF50B;
  ControlBinop cBinop_SHHgUMko;
  ControlBinop cBinop_davvgcb9;
  ControlIf cIf_jPsSPHHA;
  ControlIf cIf_BoPAi84o;
  ControlDelay cDelay_chWp4rfO;
  ControlBinop cBinop_2Nf0UGge;
  ControlBinop cBinop_gzhNJHzs;
  ControlIf cIf_6MSA6DWE;
  ControlIf cIf_nbnE3t6w;
  ControlDelay cDelay_jHM8VjWf;
  ControlBinop cBinop_NfTxT58y;
  ControlBinop cBinop_C2gUMnHF;
  ControlIf cIf_hAR3aBdN;
  ControlIf cIf_A93jpCxy;
  ControlDelay cDelay_a58R7vAF;
  ControlBinop cBinop_n1NZiQT6;
  ControlBinop cBinop_gyXFQyFr;
  SignalVarf sVarf_zm7kKFF2;
  SignalVarf sVarf_V7tRqKn9;
  SignalVarf sVarf_tSmmZGt5;
  SignalVarf sVarf_K8lwmSh7;
  SignalVarf sVarf_IQtB19Af;
  SignalVarf sVarf_dU5hNAMY;
  SignalVarf sVarf_egTAL1oX;
  SignalVarf sVarf_PB01EMCY;
  ControlVar cVar_o5ECzs93;
  ControlSlice cSlice_eF5KBtNr;
  ControlVar cVar_wgxqY0Oi;
  ControlSlice cSlice_KbXNHaAp;
  ControlVar cVar_qjfYXgBt;
  ControlSlice cSlice_5Uh47AzW;
  ControlVar cVar_EWJ64dCM;
  ControlSlice cSlice_V79YuEvs;
  ControlVar cVar_whtEv2f4;
  ControlSlice cSlice_4Y5R3uop;
  ControlVar cVar_LmS6HJtL;
  ControlDelay cDelay_n46i99q5;
  ControlVar cVar_6XxrHDIZ;
  ControlIf cIf_tIlzGX36;
  ControlIf cIf_Cm4tABHl;
  ControlBinop cBinop_N6h8Kbai;
  ControlBinop cBinop_LUeGlAKB;
  ControlBinop cBinop_MjTezGix;
  ControlBinop cBinop_lDScZvR0;
  ControlBinop cBinop_qh9EA6PB;
  ControlSlice cSlice_o2KGk3Cv;
  ControlVar cVar_Ji84dnK9;
  SignalVarf sVarf_xZLWbpzs;
  SignalVarf sVarf_MbegGErH;
  SignalVarf sVarf_PszEygMf;
  SignalVarf sVarf_eUV16DNQ;
  SignalVarf sVarf_kDpZ2dpJ;
  SignalVarf sVarf_fFRYVlaK;
  ControlBinop cBinop_BNhtZVhb;
  ControlBinop cBinop_gWEr9QT0;
  ControlVar cVar_0AQXxosv;
  SignalVarf sVarf_BcfKhW5K;
  SignalVarf sVarf_QKvnGwVR;
  SignalVarf sVarf_xJj6WuXl;
  SignalVarf sVarf_RBpwfTZi;
  ControlBinop cBinop_vkvbfDMi;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
