/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_zeeqNJPT);
  numBytes += sLine_init(&sLine_GnUEgPVV);
  numBytes += sLine_init(&sLine_QJ933Gfb);
  numBytes += sLine_init(&sLine_MiMYezHw);
  numBytes += sLine_init(&sLine_nmhDBwHH);
  numBytes += sLine_init(&sLine_4LRIWGRj);
  numBytes += sLine_init(&sLine_NcLEsPMp);
  numBytes += sLine_init(&sLine_hXpgz07j);
  numBytes += sLine_init(&sLine_sFgwHGbm);
  numBytes += sLine_init(&sLine_RTelv2dT);
  numBytes += sLine_init(&sLine_VCQD0ZuR);
  numBytes += sLine_init(&sLine_UuhYPyoC);
  numBytes += sEnv_init(&sEnv_VLW2yjeq, 512, 256);
  numBytes += sEnv_init(&sEnv_GBxkNI7z, 512, 256);
  numBytes += sLine_init(&sLine_Y6Mk3UKB);
  numBytes += sLine_init(&sLine_8GWuojOz);
  numBytes += sLine_init(&sLine_gQYA2KRZ);
  numBytes += sLine_init(&sLine_By1HqzXr);
  numBytes += sLine_init(&sLine_GFCNc8Om);
  numBytes += sLine_init(&sLine_ymDErHOy);
  numBytes += sLine_init(&sLine_3vKVOhdl);
  numBytes += sLine_init(&sLine_e6yjT1tL);
  numBytes += sLine_init(&sLine_Wq1zFKvK);
  numBytes += sLine_init(&sLine_vq2svqac);
  numBytes += sLine_init(&sLine_sJEu12YS);
  numBytes += sLine_init(&sLine_85SDR9B0);
  numBytes += sLine_init(&sLine_cl2XeX2q);
  numBytes += sLine_init(&sLine_mwTFGVsE);
  numBytes += sLine_init(&sLine_FYWjs0Rl);
  numBytes += sLine_init(&sLine_K5J18qLv);
  numBytes += sLine_init(&sLine_yv9GGVQq);
  numBytes += sLine_init(&sLine_DorU08PQ);
  numBytes += sEnv_init(&sEnv_QG5mvrzE, 512, 256);
  numBytes += sEnv_init(&sEnv_mQMk3SNJ, 512, 256);
  numBytes += sLine_init(&sLine_BBIR43x5);
  numBytes += sLine_init(&sLine_5eQi4M1k);
  numBytes += sLine_init(&sLine_GqVG9D41);
  numBytes += sLine_init(&sLine_sTS0py63);
  numBytes += sLine_init(&sLine_aN5qreTy);
  numBytes += sLine_init(&sLine_GoZbNMJ9);
  numBytes += sLine_init(&sLine_jb3jgnAG);
  numBytes += sLine_init(&sLine_WoxHOfkR);
  numBytes += cVar_init_f(&cVar_BQ9Mp3Q1, 0.0f);
  numBytes += cVar_init_f(&cVar_KndcCB0t, 0.0f);
  numBytes += cVar_init_f(&cVar_za2n6tOw, 0.0f);
  numBytes += cVar_init_f(&cVar_vyf6Eq3V, 0.0f);
  numBytes += cVar_init_f(&cVar_TYfdimWi, 0.0f);
  numBytes += cVar_init_f(&cVar_YdfZQrKO, 1.0f);
  numBytes += cVar_init_f(&cVar_1dB2M1Uh, 0.0f);
  numBytes += cVar_init_f(&cVar_ynKPTEfd, 0.0f);
  numBytes += cIf_init(&cIf_L1W1HIkn, false);
  numBytes += cIf_init(&cIf_9Z1Q1Wii, false);
  numBytes += cDelay_init(this, &cDelay_BnBEIwKF, 10.0f);
  numBytes += cIf_init(&cIf_rNQr4Tm7, false);
  numBytes += cIf_init(&cIf_Zq2h1jPX, false);
  numBytes += cDelay_init(this, &cDelay_xlVYsvbx, 10.0f);
  numBytes += cIf_init(&cIf_jryqNZWu, false);
  numBytes += cIf_init(&cIf_YmXCHIKn, false);
  numBytes += cDelay_init(this, &cDelay_GhLrcN0k, 10.0f);
  numBytes += cIf_init(&cIf_wCrn1owZ, false);
  numBytes += cIf_init(&cIf_0Jb4ISk8, false);
  numBytes += cDelay_init(this, &cDelay_GGeZB9GN, 10.0f);
  numBytes += cIf_init(&cIf_np18q6SB, false);
  numBytes += cIf_init(&cIf_2DyycHxO, false);
  numBytes += cDelay_init(this, &cDelay_C5aMll6G, 10.0f);
  numBytes += cIf_init(&cIf_2jOBTrzH, false);
  numBytes += cIf_init(&cIf_eDdfurrZ, false);
  numBytes += cDelay_init(this, &cDelay_t5JOlWnI, 10.0f);
  numBytes += cIf_init(&cIf_9G3fAkn5, false);
  numBytes += cIf_init(&cIf_3bKPLbMS, false);
  numBytes += cDelay_init(this, &cDelay_dX8n64Gd, 10.0f);
  numBytes += cIf_init(&cIf_rWB56RDO, false);
  numBytes += cIf_init(&cIf_opL72OfH, false);
  numBytes += cDelay_init(this, &cDelay_eWqtnhrH, 10.0f);
  numBytes += cIf_init(&cIf_uOPOf2bD, false);
  numBytes += cIf_init(&cIf_ycBWc2qm, false);
  numBytes += cDelay_init(this, &cDelay_J6VRRRNa, 10.0f);
  numBytes += cIf_init(&cIf_VeGiMaM7, false);
  numBytes += cIf_init(&cIf_nIksdIQH, false);
  numBytes += cDelay_init(this, &cDelay_JcCaxluq, 10.0f);
  numBytes += cIf_init(&cIf_LvA8T3QR, false);
  numBytes += cIf_init(&cIf_AjRYG946, false);
  numBytes += cDelay_init(this, &cDelay_YujwppGH, 10.0f);
  numBytes += cIf_init(&cIf_ZQG8wWDf, false);
  numBytes += cIf_init(&cIf_mBUIiSrr, false);
  numBytes += cDelay_init(this, &cDelay_pbnEX3x5, 10.0f);
  numBytes += sVarf_init(&sVarf_SSgZtIWg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GDhJSDgA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aIMpox5S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2T3Ua5Zw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WuABKvPf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fX9qyFrD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0NT2wX46, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hovVEQrb, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_kdpTA1D1, 0.0f);
  numBytes += cSlice_init(&cSlice_vJFNSN8y, 1, -1);
  numBytes += cVar_init_f(&cVar_RR3ZZy28, 1.0f);
  numBytes += cSlice_init(&cSlice_nKKGbals, 1, -1);
  numBytes += cVar_init_f(&cVar_iraNY5GX, 0.0f);
  numBytes += cSlice_init(&cSlice_l512Wwio, 1, -1);
  numBytes += cVar_init_f(&cVar_yNrXpt6w, 512.0f);
  numBytes += cSlice_init(&cSlice_69cBaYXd, 1, -1);
  numBytes += cVar_init_f(&cVar_NgdKis1Y, 1.0f);
  numBytes += cSlice_init(&cSlice_tXel4qsa, 1, -1);
  numBytes += cVar_init_f(&cVar_vshwG1zO, 1.0f);
  numBytes += cDelay_init(this, &cDelay_FqAGncs6, 20.0f);
  numBytes += cVar_init_f(&cVar_saZ4nJkP, 0.0f);
  numBytes += cIf_init(&cIf_Tvp7IF1E, false);
  numBytes += cIf_init(&cIf_tWHoKL2R, false);
  numBytes += cBinop_init(&cBinop_Eou5zVtH, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_e2BP78vE, 1, -1);
  numBytes += cVar_init_f(&cVar_qQj9RAzh, 0.0f);
  numBytes += sVarf_init(&sVarf_KckxTEJn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7uUGcLP5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2dfvGF0a, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hnOOs6rQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CM0EtZcw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mZWCLdY9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_EIbY1376, 0.0f);
  numBytes += cVar_init_f(&cVar_VQv5cgWJ, 0.0f);
  numBytes += cIf_init(&cIf_wb39iFpN, false);
  numBytes += cIf_init(&cIf_DhhR9qZC, false);
  numBytes += cDelay_init(this, &cDelay_jrPgIHW7, 10.0f);
  numBytes += cIf_init(&cIf_uUSZ8SKE, false);
  numBytes += cIf_init(&cIf_e0TVT8l1, false);
  numBytes += cDelay_init(this, &cDelay_5IkoBbA6, 10.0f);
  numBytes += cIf_init(&cIf_rC4Exh6u, false);
  numBytes += cIf_init(&cIf_0TFKN7mx, false);
  numBytes += cDelay_init(this, &cDelay_xfBPSyPb, 10.0f);
  numBytes += cIf_init(&cIf_SEs6ywFS, false);
  numBytes += cIf_init(&cIf_4n7ppdrh, false);
  numBytes += cDelay_init(this, &cDelay_adfLdnFv, 10.0f);
  numBytes += cIf_init(&cIf_y0JkhkUp, false);
  numBytes += cIf_init(&cIf_XfBpUxvv, false);
  numBytes += cDelay_init(this, &cDelay_WFzSeEIN, 10.0f);
  numBytes += cIf_init(&cIf_tUqc75fK, false);
  numBytes += cIf_init(&cIf_zSF4DeZM, false);
  numBytes += cDelay_init(this, &cDelay_M6K713bn, 10.0f);
  numBytes += cIf_init(&cIf_vasdwuJi, false);
  numBytes += cIf_init(&cIf_oiq5ovHe, false);
  numBytes += cDelay_init(this, &cDelay_lBuGMVfc, 10.0f);
  numBytes += cIf_init(&cIf_QwY2o8mb, false);
  numBytes += cIf_init(&cIf_h9BrmQeE, false);
  numBytes += cDelay_init(this, &cDelay_tkN4aXDp, 10.0f);
  numBytes += cIf_init(&cIf_T8cTApVQ, false);
  numBytes += cIf_init(&cIf_qotcEqm4, false);
  numBytes += cDelay_init(this, &cDelay_3ahiF50B, 10.0f);
  numBytes += cIf_init(&cIf_jPsSPHHA, false);
  numBytes += cIf_init(&cIf_BoPAi84o, false);
  numBytes += cDelay_init(this, &cDelay_chWp4rfO, 10.0f);
  numBytes += cIf_init(&cIf_6MSA6DWE, false);
  numBytes += cIf_init(&cIf_nbnE3t6w, false);
  numBytes += cDelay_init(this, &cDelay_jHM8VjWf, 10.0f);
  numBytes += cIf_init(&cIf_hAR3aBdN, false);
  numBytes += cIf_init(&cIf_A93jpCxy, false);
  numBytes += cDelay_init(this, &cDelay_a58R7vAF, 10.0f);
  numBytes += sVarf_init(&sVarf_zm7kKFF2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V7tRqKn9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tSmmZGt5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K8lwmSh7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IQtB19Af, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dU5hNAMY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_egTAL1oX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PB01EMCY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_o5ECzs93, 0.0f);
  numBytes += cSlice_init(&cSlice_eF5KBtNr, 1, -1);
  numBytes += cVar_init_f(&cVar_wgxqY0Oi, 1.0f);
  numBytes += cSlice_init(&cSlice_KbXNHaAp, 1, -1);
  numBytes += cVar_init_f(&cVar_qjfYXgBt, 0.0f);
  numBytes += cSlice_init(&cSlice_5Uh47AzW, 1, -1);
  numBytes += cVar_init_f(&cVar_EWJ64dCM, 512.0f);
  numBytes += cSlice_init(&cSlice_V79YuEvs, 1, -1);
  numBytes += cVar_init_f(&cVar_whtEv2f4, 1.0f);
  numBytes += cSlice_init(&cSlice_4Y5R3uop, 1, -1);
  numBytes += cVar_init_f(&cVar_LmS6HJtL, 1.0f);
  numBytes += cDelay_init(this, &cDelay_n46i99q5, 20.0f);
  numBytes += cVar_init_f(&cVar_6XxrHDIZ, 0.0f);
  numBytes += cIf_init(&cIf_tIlzGX36, false);
  numBytes += cIf_init(&cIf_Cm4tABHl, false);
  numBytes += cBinop_init(&cBinop_N6h8Kbai, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_o2KGk3Cv, 1, -1);
  numBytes += cVar_init_f(&cVar_Ji84dnK9, 0.0f);
  numBytes += sVarf_init(&sVarf_xZLWbpzs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MbegGErH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PszEygMf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eUV16DNQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kDpZ2dpJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fFRYVlaK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_0AQXxosv, 0.0f);
  numBytes += sVarf_init(&sVarf_BcfKhW5K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QKvnGwVR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xJj6WuXl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RBpwfTZi, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_VLW2yjeq);
  sEnv_free(&sEnv_GBxkNI7z);
  sEnv_free(&sEnv_QG5mvrzE);
  sEnv_free(&sEnv_mQMk3SNJ);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TpluaabN_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P9kdSzWJ_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Zlk2IyTd_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_76LbTzAk_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R3lF334e_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eZYkjVQL_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VAkYco5u_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_imFruMzG_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rFFhUGX2_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NNyPxXLy_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8ctiBTYK_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z4Y61TKt_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U5AgkAej_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x3jgsdOf_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YvR4A3K8_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2E6pJqwj_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AI4GO4ps_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hceLZNPR_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RR5NhbUP_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3RqNkJmL_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qz9ONBAg_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_BQ9Mp3Q1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ozptETRh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_b7fDYoGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_iY5sHbqz_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iY5sHbqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Iw7db3zL_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Iw7db3zL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wba9tFos_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wba9tFos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GIoeNHtO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EnJsLVmh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GIoeNHtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_d3PRJP5U_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EnJsLVmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D8PT3wDL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_d3PRJP5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0TTAHzO9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_D8PT3wDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_snxLrw99_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_snxLrw99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ISN2z9Ec_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0TTAHzO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VcxU24Dm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_ISN2z9Ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zkXDLi8p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_KndcCB0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_L24Ils5f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_za2n6tOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1HKYOX1q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_vyf6Eq3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7vspuxi9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_TYfdimWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ycC3H3d9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_YdfZQrKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LxWcItng_sendMessage);
  cMsg_lXSOxSC4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_LxWcItng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YdfZQrKO, 1, m, &cVar_YdfZQrKO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_meNqCyNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8L3UQGwB_sendMessage(_c, 0, m);
  cMsg_JFwReyyI_sendMessage(_c, 0, m);
  cMsg_nALJqmjU_sendMessage(_c, 0, m);
  cMsg_XxsHUCpP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_1dB2M1Uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6qSWikvL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_ynKPTEfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0rKNRsAz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_30wxPjYo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bG0EI83V_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1fwXsqEG_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lXVBeZTz_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hg1mhXQZ_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6E3walg8_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ebAC5gH2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_bG0EI83V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l1PvopPk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_1fwXsqEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qd7IOjzH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_lXVBeZTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QBIQj8Br_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Hg1mhXQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hWKWPH3D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_6E3walg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6iXJBlHe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_ebAC5gH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AbQRFJgH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_L1W1HIkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tfaTk5Gk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_9Z1Q1Wii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NJWaqMBW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_XteFqGUZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_das30vHX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_das30vHX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BnBEIwKF, 1, m, &cDelay_BnBEIwKF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_koGMKYCb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_BnBEIwKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BnBEIwKF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_L1W1HIkn, 0, m, &cIf_L1W1HIkn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_das30vHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BnBEIwKF, 0, m, &cDelay_BnBEIwKF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_koGMKYCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BnBEIwKF, 0, m, &cDelay_BnBEIwKF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wxcmIhEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zibbf2U6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t1EiQoQl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_k8ExTauo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VJ5NDBYi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X9NE5ZSO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VJ5NDBYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L1W1HIkn, 1, m, &cIf_L1W1HIkn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_X9NE5ZSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XteFqGUZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zibbf2U6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9Z1Q1Wii, 1, m, &cIf_9Z1Q1Wii_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_t1EiQoQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9Z1Q1Wii, 0, m, &cIf_9Z1Q1Wii_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NJWaqMBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MiMYezHw, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_tfaTk5Gk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MiMYezHw, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_rNQr4Tm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZCM7Hsxz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Zq2h1jPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KPxnExxP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_zQiyN4LD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_doWl4wSj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_doWl4wSj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xlVYsvbx, 1, m, &cDelay_xlVYsvbx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Milj0Q6t_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_xlVYsvbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xlVYsvbx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rNQr4Tm7, 0, m, &cIf_rNQr4Tm7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_doWl4wSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xlVYsvbx, 0, m, &cDelay_xlVYsvbx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Milj0Q6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xlVYsvbx, 0, m, &cDelay_xlVYsvbx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tFbEfCzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jOLoS7Yz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V74sP8R4_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_IyGxCKGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cw18xqcT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KHJE9l3L_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KHJE9l3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zQiyN4LD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_cw18xqcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rNQr4Tm7, 1, m, &cIf_rNQr4Tm7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_V74sP8R4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zq2h1jPX, 0, m, &cIf_Zq2h1jPX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jOLoS7Yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zq2h1jPX, 1, m, &cIf_Zq2h1jPX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KPxnExxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NcLEsPMp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ZCM7Hsxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NcLEsPMp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_jryqNZWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xEOjKx0z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_YmXCHIKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ubXprlan_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_cP3JJCb0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9yarkxPm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9yarkxPm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GhLrcN0k, 1, m, &cDelay_GhLrcN0k_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AAEz7qxA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_GhLrcN0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GhLrcN0k, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jryqNZWu, 0, m, &cIf_jryqNZWu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9yarkxPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GhLrcN0k, 0, m, &cDelay_GhLrcN0k_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AAEz7qxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GhLrcN0k, 0, m, &cDelay_GhLrcN0k_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8JEfRaIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AcL4UEVX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RtE01Bjt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YLg7ZOkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qC9ERzu4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tqpg3H31_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tqpg3H31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cP3JJCb0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_qC9ERzu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jryqNZWu, 1, m, &cIf_jryqNZWu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AcL4UEVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YmXCHIKn, 1, m, &cIf_YmXCHIKn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RtE01Bjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YmXCHIKn, 0, m, &cIf_YmXCHIKn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ubXprlan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RTelv2dT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xEOjKx0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RTelv2dT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_wCrn1owZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6TvEZO6B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_0Jb4ISk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VQHS4mNc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_aI3YVGcT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vHjnQM4w_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vHjnQM4w_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GGeZB9GN, 1, m, &cDelay_GGeZB9GN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ph4ReyYE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_GGeZB9GN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GGeZB9GN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wCrn1owZ, 0, m, &cIf_wCrn1owZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vHjnQM4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GGeZB9GN, 0, m, &cDelay_GGeZB9GN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ph4ReyYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GGeZB9GN, 0, m, &cDelay_GGeZB9GN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6X6pgnaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gco9yJdp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gA8LJ088_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_mvcfcfcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6AErzyqa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IS6YaCNZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IS6YaCNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aI3YVGcT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_6AErzyqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wCrn1owZ, 1, m, &cIf_wCrn1owZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gco9yJdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Jb4ISk8, 1, m, &cIf_0Jb4ISk8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gA8LJ088_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Jb4ISk8, 0, m, &cIf_0Jb4ISk8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VQHS4mNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nmhDBwHH, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_6TvEZO6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nmhDBwHH, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_np18q6SB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mphNs2i1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_2DyycHxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tBtv7U99_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ykHSt40A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3QO3jEXw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3QO3jEXw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_C5aMll6G, 1, m, &cDelay_C5aMll6G_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8nlE14XK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_C5aMll6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C5aMll6G, m);
  cIf_onMessage(_c, &Context(_c)->cIf_np18q6SB, 0, m, &cIf_np18q6SB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3QO3jEXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_C5aMll6G, 0, m, &cDelay_C5aMll6G_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8nlE14XK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C5aMll6G, 0, m, &cDelay_C5aMll6G_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_d6XnGYI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jqBVCzVZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HzmdNz5Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3RAx0162_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C6njOpvA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jqb4PMsJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_C6njOpvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_np18q6SB, 1, m, &cIf_np18q6SB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jqb4PMsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ykHSt40A_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_HzmdNz5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2DyycHxO, 0, m, &cIf_2DyycHxO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jqBVCzVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2DyycHxO, 1, m, &cIf_2DyycHxO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tBtv7U99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hXpgz07j, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_mphNs2i1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hXpgz07j, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_2jOBTrzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XRffICZJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_eDdfurrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xZCT8iIW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_sIU8jLoE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YHrBZUzY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YHrBZUzY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_t5JOlWnI, 1, m, &cDelay_t5JOlWnI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cLIG6uIa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_t5JOlWnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_t5JOlWnI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2jOBTrzH, 0, m, &cIf_2jOBTrzH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YHrBZUzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_t5JOlWnI, 0, m, &cDelay_t5JOlWnI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cLIG6uIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_t5JOlWnI, 0, m, &cDelay_t5JOlWnI_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_frTn16tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kv8Gjte0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OXPE527G_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_t51vyR7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XCTsw4Z3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JSjlkuCn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JSjlkuCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sIU8jLoE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_XCTsw4Z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2jOBTrzH, 1, m, &cIf_2jOBTrzH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kv8Gjte0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eDdfurrZ, 1, m, &cIf_eDdfurrZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OXPE527G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eDdfurrZ, 0, m, &cIf_eDdfurrZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xZCT8iIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VCQD0ZuR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_XRffICZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VCQD0ZuR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_9G3fAkn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ul3rliRA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_3bKPLbMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_k79Scme5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_kVJ2OTzp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LYW7upkU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LYW7upkU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dX8n64Gd, 1, m, &cDelay_dX8n64Gd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WZ65inDp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_dX8n64Gd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dX8n64Gd, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9G3fAkn5, 0, m, &cIf_9G3fAkn5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LYW7upkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dX8n64Gd, 0, m, &cDelay_dX8n64Gd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WZ65inDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dX8n64Gd, 0, m, &cDelay_dX8n64Gd_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3yu3J6Qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c2Lt7Bh4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UQCCnO7T_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6CkvPSHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QVQD2Zse_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xGPnRtVz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QVQD2Zse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9G3fAkn5, 1, m, &cIf_9G3fAkn5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xGPnRtVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kVJ2OTzp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_UQCCnO7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3bKPLbMS, 0, m, &cIf_3bKPLbMS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_c2Lt7Bh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3bKPLbMS, 1, m, &cIf_3bKPLbMS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_k79Scme5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4LRIWGRj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ul3rliRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4LRIWGRj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_rWB56RDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NFdi7nZ6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_opL72OfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XjHrk2ZC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_4X6QdL6L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_zNmdVWEa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_zNmdVWEa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_eWqtnhrH, 1, m, &cDelay_eWqtnhrH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mHpQ5RYc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_eWqtnhrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eWqtnhrH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rWB56RDO, 0, m, &cIf_rWB56RDO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zNmdVWEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eWqtnhrH, 0, m, &cDelay_eWqtnhrH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mHpQ5RYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eWqtnhrH, 0, m, &cDelay_eWqtnhrH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_m3Kqbj8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pRIUgmy5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cNg97iDK_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_syVSZcU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XOQdUWD7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V3TnptrY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_V3TnptrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4X6QdL6L_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_XOQdUWD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rWB56RDO, 1, m, &cIf_rWB56RDO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cNg97iDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_opL72OfH, 0, m, &cIf_opL72OfH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pRIUgmy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_opL72OfH, 1, m, &cIf_opL72OfH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XjHrk2ZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sFgwHGbm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NFdi7nZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sFgwHGbm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_uOPOf2bD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QkdzoW3P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ycBWc2qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EesNzJf7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_kVzmAVMS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_J36TE5dv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_J36TE5dv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_J6VRRRNa, 1, m, &cDelay_J6VRRRNa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4h4gmmNA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_J6VRRRNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_J6VRRRNa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uOPOf2bD, 0, m, &cIf_uOPOf2bD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_J36TE5dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_J6VRRRNa, 0, m, &cDelay_J6VRRRNa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4h4gmmNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_J6VRRRNa, 0, m, &cDelay_J6VRRRNa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_A40XFMHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pz3scgqo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MPaxouJw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_n1PNXClK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yy6kwUVz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x7ZVwglr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yy6kwUVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uOPOf2bD, 1, m, &cIf_uOPOf2bD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_x7ZVwglr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kVzmAVMS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_pz3scgqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ycBWc2qm, 1, m, &cIf_ycBWc2qm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MPaxouJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ycBWc2qm, 0, m, &cIf_ycBWc2qm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EesNzJf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UuhYPyoC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QkdzoW3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UuhYPyoC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_VeGiMaM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BEOgeamm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_nIksdIQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4voiavrm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_xSKkdSVk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lbC5zVzY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lbC5zVzY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JcCaxluq, 1, m, &cDelay_JcCaxluq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MMqwDKIA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_JcCaxluq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JcCaxluq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VeGiMaM7, 0, m, &cIf_VeGiMaM7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lbC5zVzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JcCaxluq, 0, m, &cDelay_JcCaxluq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MMqwDKIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JcCaxluq, 0, m, &cDelay_JcCaxluq_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wCrDKngs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UoIGaKz6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ryGn2Gy_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Q9BSceO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H7UM82OF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EiCVyWDt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EiCVyWDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xSKkdSVk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_H7UM82OF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VeGiMaM7, 1, m, &cIf_VeGiMaM7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UoIGaKz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nIksdIQH, 1, m, &cIf_nIksdIQH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0ryGn2Gy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nIksdIQH, 0, m, &cIf_nIksdIQH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4voiavrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zeeqNJPT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BEOgeamm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zeeqNJPT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_LvA8T3QR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8dOBuLuz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_AjRYG946_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IMemNcDK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_1akykEIJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_q4uC7iXB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_q4uC7iXB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YujwppGH, 1, m, &cDelay_YujwppGH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W3BYZdzN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_YujwppGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YujwppGH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LvA8T3QR, 0, m, &cIf_LvA8T3QR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_q4uC7iXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YujwppGH, 0, m, &cDelay_YujwppGH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_W3BYZdzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YujwppGH, 0, m, &cDelay_YujwppGH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7VToRYEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6vfYVuxd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2hU6bfpf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0Fqg6Sb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NN5jiMFn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W5Hb96uy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_W5Hb96uy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1akykEIJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_NN5jiMFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LvA8T3QR, 1, m, &cIf_LvA8T3QR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6vfYVuxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AjRYG946, 1, m, &cIf_AjRYG946_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2hU6bfpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AjRYG946, 0, m, &cIf_AjRYG946_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IMemNcDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GnUEgPVV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_8dOBuLuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GnUEgPVV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ZQG8wWDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lGNI43pn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_mBUIiSrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TatA7czK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_9FCunVSE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8wr0GLgj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8wr0GLgj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pbnEX3x5, 1, m, &cDelay_pbnEX3x5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bhGsuCnd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_pbnEX3x5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pbnEX3x5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZQG8wWDf, 0, m, &cIf_ZQG8wWDf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8wr0GLgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pbnEX3x5, 0, m, &cDelay_pbnEX3x5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bhGsuCnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pbnEX3x5, 0, m, &cDelay_pbnEX3x5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_WlYZSy6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MsSQrqJB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wnkoQciv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FDV760Ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gdey9x68_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zfcoWsrB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zfcoWsrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9FCunVSE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Gdey9x68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZQG8wWDf, 1, m, &cIf_ZQG8wWDf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wnkoQciv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mBUIiSrr, 0, m, &cIf_mBUIiSrr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MsSQrqJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mBUIiSrr, 1, m, &cIf_mBUIiSrr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TatA7czK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QJ933Gfb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_lGNI43pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QJ933Gfb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_l1PvopPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_P3GxIgbO_sendMessage(_c, 0, m);
  cMsg_zCKdoCiP_sendMessage(_c, 0, m);
  cMsg_qFGQKCXr_sendMessage(_c, 0, m);
  cMsg_p4R4zQOc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_qd7IOjzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_P3GxIgbO_sendMessage(_c, 0, m);
  cMsg_rLkTtR1A_sendMessage(_c, 0, m);
  cMsg_VLyIFfcf_sendMessage(_c, 0, m);
  cMsg_ji5oGUUE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_QBIQj8Br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_bR5XxcrN_sendMessage(_c, 0, m);
  cMsg_rLkTtR1A_sendMessage(_c, 0, m);
  cMsg_p4R4zQOc_sendMessage(_c, 0, m);
  cMsg_61uPTzYX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hWKWPH3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_bR5XxcrN_sendMessage(_c, 0, m);
  cMsg_iDn87IGJ_sendMessage(_c, 0, m);
  cMsg_qFGQKCXr_sendMessage(_c, 0, m);
  cMsg_V7sjaPFD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_6iXJBlHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_D5SIQfmz_sendMessage(_c, 0, m);
  cMsg_ji5oGUUE_sendMessage(_c, 0, m);
  cMsg_HXICvz8J_sendMessage(_c, 0, m);
  cMsg_qFGQKCXr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_AbQRFJgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_D5SIQfmz_sendMessage(_c, 0, m);
  cMsg_V7sjaPFD_sendMessage(_c, 0, m);
  cMsg_rLkTtR1A_sendMessage(_c, 0, m);
  cMsg_iRS8ZsEe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_O6xphXzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k8ExTauo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wxcmIhEB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_K8u8oRGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k8ExTauo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wxcmIhEB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EqIlKAvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IyGxCKGz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tFbEfCzG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0LSIHdgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IyGxCKGz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tFbEfCzG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qgkV9W2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YLg7ZOkg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8JEfRaIX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vp52g28y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YLg7ZOkg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8JEfRaIX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_P3GxIgbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_O6xphXzd_sendMessage(_c, 0, m);
  cMsg_0LSIHdgr_sendMessage(_c, 0, m);
  cMsg_vp52g28y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bR5XxcrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_K8u8oRGd_sendMessage(_c, 0, m);
  cMsg_EqIlKAvR_sendMessage(_c, 0, m);
  cMsg_vp52g28y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_D5SIQfmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_K8u8oRGd_sendMessage(_c, 0, m);
  cMsg_0LSIHdgr_sendMessage(_c, 0, m);
  cMsg_qgkV9W2W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_G7e3tBPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mvcfcfcG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6X6pgnaG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gr5efCbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mvcfcfcG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6X6pgnaG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6ajpZzeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3RAx0162_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d6XnGYI3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_m51NEBlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3RAx0162_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d6XnGYI3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Pu10tOAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t51vyR7G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_frTn16tg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WZzOY4wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t51vyR7G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_frTn16tg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rLkTtR1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_gr5efCbp_sendMessage(_c, 0, m);
  cMsg_m51NEBlJ_sendMessage(_c, 0, m);
  cMsg_WZzOY4wj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zCKdoCiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_gr5efCbp_sendMessage(_c, 0, m);
  cMsg_6ajpZzeH_sendMessage(_c, 0, m);
  cMsg_Pu10tOAg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_iDn87IGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_G7e3tBPr_sendMessage(_c, 0, m);
  cMsg_m51NEBlJ_sendMessage(_c, 0, m);
  cMsg_Pu10tOAg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_AwGRCqke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q9BSceO5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wCrDKngs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bKdQNbnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q9BSceO5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wCrDKngs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_T24uUdzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0Fqg6Sb6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7VToRYEy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9fjboZtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0Fqg6Sb6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7VToRYEy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bAOeW2kA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FDV760Ah_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WlYZSy6u_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zaAdz5sa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FDV760Ah_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WlYZSy6u_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_V7sjaPFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_AwGRCqke_sendMessage(_c, 0, m);
  cMsg_9fjboZtG_sendMessage(_c, 0, m);
  cMsg_zaAdz5sa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ji5oGUUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_bKdQNbnH_sendMessage(_c, 0, m);
  cMsg_T24uUdzn_sendMessage(_c, 0, m);
  cMsg_zaAdz5sa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_p4R4zQOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_bKdQNbnH_sendMessage(_c, 0, m);
  cMsg_9fjboZtG_sendMessage(_c, 0, m);
  cMsg_bAOeW2kA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_3ki8iBhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6CkvPSHd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3yu3J6Qa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7MfP46Z6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6CkvPSHd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3yu3J6Qa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_r7FBloxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_syVSZcU8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m3Kqbj8F_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_u5zriyNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_syVSZcU8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m3Kqbj8F_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Z1it9OJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n1PNXClK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_A40XFMHv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2wQlhwSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n1PNXClK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_A40XFMHv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qFGQKCXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_7MfP46Z6_sendMessage(_c, 0, m);
  cMsg_u5zriyNg_sendMessage(_c, 0, m);
  cMsg_2wQlhwSC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_VLyIFfcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_7MfP46Z6_sendMessage(_c, 0, m);
  cMsg_r7FBloxG_sendMessage(_c, 0, m);
  cMsg_Z1it9OJu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_iRS8ZsEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_3ki8iBhC_sendMessage(_c, 0, m);
  cMsg_r7FBloxG_sendMessage(_c, 0, m);
  cMsg_2wQlhwSC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HXICvz8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_G7e3tBPr_sendMessage(_c, 0, m);
  cMsg_6ajpZzeH_sendMessage(_c, 0, m);
  cMsg_WZzOY4wj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_61uPTzYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_3ki8iBhC_sendMessage(_c, 0, m);
  cMsg_u5zriyNg_sendMessage(_c, 0, m);
  cMsg_Z1it9OJu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_kdpTA1D1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tViSv23T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_ByiYBOB6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vJFNSN8y, 0, m, &cSlice_vJFNSN8y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JzpC7g9w_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_vJFNSN8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_65tdMkY6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_65tdMkY6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_RR3ZZy28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_65tdMkY6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_65tdMkY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NNyPxXLy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_x3Ag1FCQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nKKGbals, 0, m, &cSlice_nKKGbals_sendMessage);
      break;
    }
    default: {
      cSwitchcase_a14ailup_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_nKKGbals_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BNYNus8g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BNYNus8g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_iraNY5GX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BNYNus8g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_BNYNus8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_x3jgsdOf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_a14ailup_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_l512Wwio, 0, m, &cSlice_l512Wwio_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ByiYBOB6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_l512Wwio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jK6UscrH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jK6UscrH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_yNrXpt6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jK6UscrH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_jK6UscrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rFFhUGX2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_JzpC7g9w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_69cBaYXd, 0, m, &cSlice_69cBaYXd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VyohtFBk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_69cBaYXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9Qx4c4AK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9Qx4c4AK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_NgdKis1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9Qx4c4AK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_9Qx4c4AK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U5AgkAej_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_VyohtFBk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tXel4qsa, 0, m, &cSlice_tXel4qsa_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wRBwx4co_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_tXel4qsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hbdPHI2l_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hbdPHI2l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_vshwG1zO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hbdPHI2l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_hbdPHI2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Z4Y61TKt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_zS7CLcQ3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Vdv4Zlri_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Vdv4Zlri_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FqAGncs6, 1, m, &cDelay_FqAGncs6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6UfI5G0V_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_FqAGncs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FqAGncs6, m);
  cMsg_NrPA5zsl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Vdv4Zlri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FqAGncs6, 0, m, &cDelay_FqAGncs6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6UfI5G0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FqAGncs6, 0, m, &cDelay_FqAGncs6_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_saZ4nJkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eou5zVtH, HV_BINOP_SUBTRACT, 0, m, &cBinop_Eou5zVtH_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_Tvp7IF1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0cPyTcXq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_tWHoKL2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0cPyTcXq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_VLW2yjeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_saZ4nJkP, 0, m, &cVar_saZ4nJkP_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_GBxkNI7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EyK9t4fU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IqXoiu5Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ume4A8rt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Eou5zVtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oE5fxAep_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_oE5fxAep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3Dr6ea5q_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3Dr6ea5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_I4Xg4wuc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_l5pT8I8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KG98BV2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hHyBn6gM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hHyBn6gM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rntNrAXz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_4KG98BV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Tvp7IF1E, 1, m, &cIf_Tvp7IF1E_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_61qBF6gb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tWHoKL2R, 1, m, &cIf_tWHoKL2R_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rntNrAXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Tvp7IF1E, 0, m, &cIf_Tvp7IF1E_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_I4Xg4wuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tWHoKL2R, 0, m, &cIf_tWHoKL2R_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EyK9t4fU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_IqXoiu5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Eou5zVtH, HV_BINOP_SUBTRACT, 1, m, &cBinop_Eou5zVtH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ume4A8rt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_saZ4nJkP, 0, m, &cVar_saZ4nJkP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0cPyTcXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y6Mk3UKB, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_wRBwx4co_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_e2BP78vE, 0, m, &cSlice_e2BP78vE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_e2BP78vE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ye3b6iq8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ye3b6iq8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_qQj9RAzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ye3b6iq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_ye3b6iq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8ctiBTYK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_6qSWikvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ymDErHOy, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0rKNRsAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_By1HqzXr, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_nvfyTidR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ynKPTEfd, 0, m, &cVar_ynKPTEfd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tViSv23T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GFCNc8Om, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_KcEvydpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zS7CLcQ3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_NNHWLFUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vG6O8jAy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_NrPA5zsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8GWuojOz, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_vG6O8jAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8GWuojOz, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ZJSMTNZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_EJCa6eMR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_EJCa6eMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vgQLCFMD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_vgQLCFMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gQYA2KRZ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_EIbY1376_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RU2VjeTM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_VQv5cgWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bNLH8lkR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_MeOAr7MB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CkiCuxw8_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aKxXr1YN_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wBbrLtbh_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3uVXZ5lz_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_voOhxTRQ_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RcfPCYWN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_CkiCuxw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qhhiVdax_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_aKxXr1YN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_38XfqOlA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_wBbrLtbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xDvrBDua_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_3uVXZ5lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cTF6jGFM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_voOhxTRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DVuIOeZV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_RcfPCYWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2qiprC89_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_wb39iFpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_r0Nxadgk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_DhhR9qZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GfbNS5Iu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_I1PYm15N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RymeRidQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RymeRidQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jrPgIHW7, 1, m, &cDelay_jrPgIHW7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zwVqDIj8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_jrPgIHW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jrPgIHW7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wb39iFpN, 0, m, &cIf_wb39iFpN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RymeRidQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jrPgIHW7, 0, m, &cDelay_jrPgIHW7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zwVqDIj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jrPgIHW7, 0, m, &cDelay_jrPgIHW7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_H9GVn63J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qDeJE0zc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PX0AjT4D_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0eRf8EsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KWswbSMx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kzpTH9JH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kzpTH9JH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_I1PYm15N_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_KWswbSMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wb39iFpN, 1, m, &cIf_wb39iFpN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PX0AjT4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DhhR9qZC, 0, m, &cIf_DhhR9qZC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qDeJE0zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DhhR9qZC, 1, m, &cIf_DhhR9qZC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GfbNS5Iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vq2svqac, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_r0Nxadgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vq2svqac, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_uUSZ8SKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Lfuwj8nW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_e0TVT8l1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SdxOQwkZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5d6Qv7UX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_THsdfjia_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_THsdfjia_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5IkoBbA6, 1, m, &cDelay_5IkoBbA6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u4r6hDV0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_5IkoBbA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5IkoBbA6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uUSZ8SKE, 0, m, &cIf_uUSZ8SKE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_THsdfjia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5IkoBbA6, 0, m, &cDelay_5IkoBbA6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_u4r6hDV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5IkoBbA6, 0, m, &cDelay_5IkoBbA6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ehy2E1Aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9GShbqhg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ObEtvl9l_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Sp8cD0BX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m3Bp2H0T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2SQFBxJC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_m3Bp2H0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uUSZ8SKE, 1, m, &cIf_uUSZ8SKE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2SQFBxJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5d6Qv7UX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_ObEtvl9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e0TVT8l1, 0, m, &cIf_e0TVT8l1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9GShbqhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e0TVT8l1, 1, m, &cIf_e0TVT8l1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SdxOQwkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cl2XeX2q, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Lfuwj8nW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cl2XeX2q, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_rC4Exh6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0ybpNlR7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_0TFKN7mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yxJgZdbA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_vHZgXJID_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ydLPOpyn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ydLPOpyn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xfBPSyPb, 1, m, &cDelay_xfBPSyPb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KjsVtGBh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_xfBPSyPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xfBPSyPb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rC4Exh6u, 0, m, &cIf_rC4Exh6u_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ydLPOpyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xfBPSyPb, 0, m, &cDelay_xfBPSyPb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KjsVtGBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xfBPSyPb, 0, m, &cDelay_xfBPSyPb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_soazeXSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VGDoQbwO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cut49wx5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_QtexksGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ooq4VnVs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xdkK5Tdg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xdkK5Tdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vHZgXJID_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_ooq4VnVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rC4Exh6u, 1, m, &cIf_rC4Exh6u_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Cut49wx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0TFKN7mx, 0, m, &cIf_0TFKN7mx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VGDoQbwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0TFKN7mx, 1, m, &cIf_0TFKN7mx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yxJgZdbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K5J18qLv, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0ybpNlR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K5J18qLv, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_SEs6ywFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KZO9VTAO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_4n7ppdrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BrwF20Jd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ltR5M8uu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XE0GElB5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XE0GElB5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_adfLdnFv, 1, m, &cDelay_adfLdnFv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rOCZUVe4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_adfLdnFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_adfLdnFv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SEs6ywFS, 0, m, &cIf_SEs6ywFS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XE0GElB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_adfLdnFv, 0, m, &cDelay_adfLdnFv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rOCZUVe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_adfLdnFv, 0, m, &cDelay_adfLdnFv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gfUyxw9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O0DCBIFm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sxdYFKEX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3S5P8rhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y61yTRAA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sCFLpN9D_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sCFLpN9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ltR5M8uu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Y61yTRAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SEs6ywFS, 1, m, &cIf_SEs6ywFS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_O0DCBIFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4n7ppdrh, 1, m, &cIf_4n7ppdrh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sxdYFKEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4n7ppdrh, 0, m, &cIf_4n7ppdrh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BrwF20Jd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sJEu12YS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KZO9VTAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sJEu12YS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_y0JkhkUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xg0xuimZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_XfBpUxvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FPRnovLM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_LV0nN1dA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_a1wasEN2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_a1wasEN2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WFzSeEIN, 1, m, &cDelay_WFzSeEIN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6osl0GNO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_WFzSeEIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WFzSeEIN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_y0JkhkUp, 0, m, &cIf_y0JkhkUp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_a1wasEN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WFzSeEIN, 0, m, &cDelay_WFzSeEIN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6osl0GNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WFzSeEIN, 0, m, &cDelay_WFzSeEIN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JetsNtAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_powDUnfU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_41hUmRD9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_O3rZpbyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VDrdoCLB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qNuatrcW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qNuatrcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LV0nN1dA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_VDrdoCLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y0JkhkUp, 1, m, &cIf_y0JkhkUp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_powDUnfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XfBpUxvv, 1, m, &cIf_XfBpUxvv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_41hUmRD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XfBpUxvv, 0, m, &cIf_XfBpUxvv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FPRnovLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mwTFGVsE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xg0xuimZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mwTFGVsE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_tUqc75fK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3ts1s9bX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_zSF4DeZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zRbXvUTo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Joaim9x4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9llw5lCj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9llw5lCj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_M6K713bn, 1, m, &cDelay_M6K713bn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7j2MPVQs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_M6K713bn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M6K713bn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tUqc75fK, 0, m, &cIf_tUqc75fK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9llw5lCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_M6K713bn, 0, m, &cDelay_M6K713bn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7j2MPVQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M6K713bn, 0, m, &cDelay_M6K713bn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_zaCTizaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DrLbT2Ya_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TnbbNsmt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PXWQt9PW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t9mhyyZq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vXSBmWQz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_t9mhyyZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tUqc75fK, 1, m, &cIf_tUqc75fK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vXSBmWQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Joaim9x4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_DrLbT2Ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zSF4DeZM, 1, m, &cIf_zSF4DeZM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TnbbNsmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zSF4DeZM, 0, m, &cIf_zSF4DeZM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zRbXvUTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yv9GGVQq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_3ts1s9bX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yv9GGVQq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_vasdwuJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uh4O8d3E_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_oiq5ovHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UxOcDBWM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_aglppde2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0FDaX6SI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0FDaX6SI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lBuGMVfc, 1, m, &cDelay_lBuGMVfc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZJPZ8IJo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_lBuGMVfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lBuGMVfc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vasdwuJi, 0, m, &cIf_vasdwuJi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0FDaX6SI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lBuGMVfc, 0, m, &cDelay_lBuGMVfc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZJPZ8IJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lBuGMVfc, 0, m, &cDelay_lBuGMVfc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qon4HxMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mntFbJOI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WR4KS1N7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KTlzwlJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sp5phP1z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mzbAWv57_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mzbAWv57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aglppde2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Sp5phP1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vasdwuJi, 1, m, &cIf_vasdwuJi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WR4KS1N7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oiq5ovHe, 0, m, &cIf_oiq5ovHe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mntFbJOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oiq5ovHe, 1, m, &cIf_oiq5ovHe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UxOcDBWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_85SDR9B0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_uh4O8d3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_85SDR9B0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_QwY2o8mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NOfqOl8R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_h9BrmQeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yPDB7vfI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_dNTWEO0t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6w4PSx3C_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6w4PSx3C_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tkN4aXDp, 1, m, &cDelay_tkN4aXDp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DpC6eEfN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_tkN4aXDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tkN4aXDp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QwY2o8mb, 0, m, &cIf_QwY2o8mb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6w4PSx3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tkN4aXDp, 0, m, &cDelay_tkN4aXDp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DpC6eEfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tkN4aXDp, 0, m, &cDelay_tkN4aXDp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_m5113r6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6oNqAHfP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gsvn2Sf4_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AEmvqm7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YYrSeYwT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CVs95pJr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CVs95pJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dNTWEO0t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_YYrSeYwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QwY2o8mb, 1, m, &cIf_QwY2o8mb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gsvn2Sf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h9BrmQeE, 0, m, &cIf_h9BrmQeE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6oNqAHfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h9BrmQeE, 1, m, &cIf_h9BrmQeE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yPDB7vfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FYWjs0Rl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NOfqOl8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FYWjs0Rl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_T8cTApVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NURSajxb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_qotcEqm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ijrLoqwu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5rPZaUu2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tVJCoShB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tVJCoShB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3ahiF50B, 1, m, &cDelay_3ahiF50B_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TxAd3FVK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_3ahiF50B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3ahiF50B, m);
  cIf_onMessage(_c, &Context(_c)->cIf_T8cTApVQ, 0, m, &cIf_T8cTApVQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tVJCoShB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3ahiF50B, 0, m, &cDelay_3ahiF50B_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TxAd3FVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3ahiF50B, 0, m, &cDelay_3ahiF50B_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_SHHgUMko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I5s8edc0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MqJXHzEQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_davvgcb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QE9KjsHV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6tRSE1RO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6tRSE1RO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5rPZaUu2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_QE9KjsHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T8cTApVQ, 1, m, &cIf_T8cTApVQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_I5s8edc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qotcEqm4, 1, m, &cIf_qotcEqm4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MqJXHzEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qotcEqm4, 0, m, &cIf_qotcEqm4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ijrLoqwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DorU08PQ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NURSajxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DorU08PQ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_jPsSPHHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0oBckRqQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_BoPAi84o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s0NYattH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_cDbV7S5U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_58P61aA1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_58P61aA1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_chWp4rfO, 1, m, &cDelay_chWp4rfO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FmnEKyeZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_chWp4rfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_chWp4rfO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jPsSPHHA, 0, m, &cIf_jPsSPHHA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_58P61aA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_chWp4rfO, 0, m, &cDelay_chWp4rfO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FmnEKyeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_chWp4rfO, 0, m, &cDelay_chWp4rfO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2Nf0UGge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tAUhEjt3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vyqQc1K9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gzhNJHzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SkhOuB5A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cJGbHmud_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SkhOuB5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jPsSPHHA, 1, m, &cIf_jPsSPHHA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cJGbHmud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cDbV7S5U_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_vyqQc1K9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BoPAi84o, 0, m, &cIf_BoPAi84o_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tAUhEjt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BoPAi84o, 1, m, &cIf_BoPAi84o_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_s0NYattH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3vKVOhdl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0oBckRqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3vKVOhdl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_6MSA6DWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nMydzlP3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_nbnE3t6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bkLt4uDe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_OI2ZF21T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jIByQ6iW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jIByQ6iW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jHM8VjWf, 1, m, &cDelay_jHM8VjWf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2xcK9y3u_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_jHM8VjWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jHM8VjWf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6MSA6DWE, 0, m, &cIf_6MSA6DWE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jIByQ6iW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jHM8VjWf, 0, m, &cDelay_jHM8VjWf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2xcK9y3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jHM8VjWf, 0, m, &cDelay_jHM8VjWf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_NfTxT58y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CDsByVHZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pIJ91Ksp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_C2gUMnHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iMM1P7aL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yd42e4ET_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iMM1P7aL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6MSA6DWE, 1, m, &cIf_6MSA6DWE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yd42e4ET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OI2ZF21T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_CDsByVHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nbnE3t6w, 1, m, &cIf_nbnE3t6w_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pIJ91Ksp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nbnE3t6w, 0, m, &cIf_nbnE3t6w_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bkLt4uDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e6yjT1tL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_nMydzlP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e6yjT1tL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_hAR3aBdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QUmjtPPM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_A93jpCxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PoL91E0c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_WEuLOU0g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FMA2eQxO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FMA2eQxO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_a58R7vAF, 1, m, &cDelay_a58R7vAF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MG8G5EuC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_a58R7vAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a58R7vAF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_hAR3aBdN, 0, m, &cIf_hAR3aBdN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FMA2eQxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_a58R7vAF, 0, m, &cDelay_a58R7vAF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MG8G5EuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_a58R7vAF, 0, m, &cDelay_a58R7vAF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_n1NZiQT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_91hdRuhG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KTbMwJwp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gyXFQyFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lz8UMpCs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KpLILilb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KpLILilb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WEuLOU0g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Lz8UMpCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hAR3aBdN, 1, m, &cIf_hAR3aBdN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KTbMwJwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A93jpCxy, 0, m, &cIf_A93jpCxy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_91hdRuhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A93jpCxy, 1, m, &cIf_A93jpCxy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PoL91E0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wq1zFKvK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QUmjtPPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wq1zFKvK, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_qhhiVdax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_BTEXBo5V_sendMessage(_c, 0, m);
  cMsg_4UU7jYBq_sendMessage(_c, 0, m);
  cMsg_OiyfP5M3_sendMessage(_c, 0, m);
  cMsg_zjSNaRxi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_38XfqOlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_BTEXBo5V_sendMessage(_c, 0, m);
  cMsg_D5bR187N_sendMessage(_c, 0, m);
  cMsg_CVBwMEig_sendMessage(_c, 0, m);
  cMsg_CXW6FQ04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xDvrBDua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_zQ5uCHWR_sendMessage(_c, 0, m);
  cMsg_D5bR187N_sendMessage(_c, 0, m);
  cMsg_zjSNaRxi_sendMessage(_c, 0, m);
  cMsg_lSlXRy2e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_cTF6jGFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_zQ5uCHWR_sendMessage(_c, 0, m);
  cMsg_vMRzPvUY_sendMessage(_c, 0, m);
  cMsg_OiyfP5M3_sendMessage(_c, 0, m);
  cMsg_WLql5oEr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_DVuIOeZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_lYPObPyK_sendMessage(_c, 0, m);
  cMsg_CXW6FQ04_sendMessage(_c, 0, m);
  cMsg_DG3e5ENZ_sendMessage(_c, 0, m);
  cMsg_OiyfP5M3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_2qiprC89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_lYPObPyK_sendMessage(_c, 0, m);
  cMsg_WLql5oEr_sendMessage(_c, 0, m);
  cMsg_D5bR187N_sendMessage(_c, 0, m);
  cMsg_eJCGDGVa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bnYCAnqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0eRf8EsT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H9GVn63J_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IvnykIGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0eRf8EsT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H9GVn63J_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wNVBaly8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Sp8cD0BX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ehy2E1Aa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yvjgX9zU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Sp8cD0BX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ehy2E1Aa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3aYUKF5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QtexksGL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_soazeXSP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0vAivVcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QtexksGL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_soazeXSP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BTEXBo5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_bnYCAnqN_sendMessage(_c, 0, m);
  cMsg_yvjgX9zU_sendMessage(_c, 0, m);
  cMsg_0vAivVcT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zQ5uCHWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_IvnykIGA_sendMessage(_c, 0, m);
  cMsg_wNVBaly8_sendMessage(_c, 0, m);
  cMsg_0vAivVcT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_lYPObPyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_IvnykIGA_sendMessage(_c, 0, m);
  cMsg_yvjgX9zU_sendMessage(_c, 0, m);
  cMsg_3aYUKF5z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_siJp3Mis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3S5P8rhF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gfUyxw9O_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HNJBGxgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3S5P8rhF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gfUyxw9O_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oWVWS5Hp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O3rZpbyu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JetsNtAV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2inZhHar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O3rZpbyu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JetsNtAV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YVN5u1gM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PXWQt9PW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zaCTizaz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_socKUISw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PXWQt9PW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zaCTizaz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_D5bR187N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_HNJBGxgx_sendMessage(_c, 0, m);
  cMsg_2inZhHar_sendMessage(_c, 0, m);
  cMsg_socKUISw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4UU7jYBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_HNJBGxgx_sendMessage(_c, 0, m);
  cMsg_oWVWS5Hp_sendMessage(_c, 0, m);
  cMsg_YVN5u1gM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_vMRzPvUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_siJp3Mis_sendMessage(_c, 0, m);
  cMsg_2inZhHar_sendMessage(_c, 0, m);
  cMsg_YVN5u1gM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_G9nBoSqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gzhNJHzs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2Nf0UGge_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UC0TTOuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gzhNJHzs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2Nf0UGge_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WPkldtPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C2gUMnHF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NfTxT58y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_z9ftDMLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C2gUMnHF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NfTxT58y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rOl1kLGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gyXFQyFr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n1NZiQT6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_P25oa0St_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gyXFQyFr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n1NZiQT6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WLql5oEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_G9nBoSqg_sendMessage(_c, 0, m);
  cMsg_z9ftDMLA_sendMessage(_c, 0, m);
  cMsg_P25oa0St_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CXW6FQ04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_UC0TTOuL_sendMessage(_c, 0, m);
  cMsg_WPkldtPz_sendMessage(_c, 0, m);
  cMsg_P25oa0St_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zjSNaRxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_UC0TTOuL_sendMessage(_c, 0, m);
  cMsg_z9ftDMLA_sendMessage(_c, 0, m);
  cMsg_rOl1kLGK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_FWNu62Tl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KTlzwlJX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qon4HxMF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dqnqkS89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KTlzwlJX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qon4HxMF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jxQ5Q90u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AEmvqm7y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m5113r6h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TRspgEyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AEmvqm7y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m5113r6h_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_O9lwqIz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_davvgcb9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SHHgUMko_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qOsJUUmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_davvgcb9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SHHgUMko_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OiyfP5M3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_dqnqkS89_sendMessage(_c, 0, m);
  cMsg_TRspgEyc_sendMessage(_c, 0, m);
  cMsg_qOsJUUmQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CVBwMEig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_dqnqkS89_sendMessage(_c, 0, m);
  cMsg_jxQ5Q90u_sendMessage(_c, 0, m);
  cMsg_O9lwqIz8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_eJCGDGVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_FWNu62Tl_sendMessage(_c, 0, m);
  cMsg_jxQ5Q90u_sendMessage(_c, 0, m);
  cMsg_qOsJUUmQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_DG3e5ENZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_siJp3Mis_sendMessage(_c, 0, m);
  cMsg_oWVWS5Hp_sendMessage(_c, 0, m);
  cMsg_socKUISw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_lSlXRy2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_FWNu62Tl_sendMessage(_c, 0, m);
  cMsg_TRspgEyc_sendMessage(_c, 0, m);
  cMsg_O9lwqIz8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_o5ECzs93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lmj7par9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_BfazAu2M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eF5KBtNr, 0, m, &cSlice_eF5KBtNr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qflEAIa8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_eF5KBtNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_usxU1iZf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_usxU1iZf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_wgxqY0Oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_usxU1iZf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_usxU1iZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2E6pJqwj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Ch1TWavf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KbXNHaAp, 0, m, &cSlice_KbXNHaAp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kplz3XFQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_KbXNHaAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dQUGo1Fy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dQUGo1Fy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_qjfYXgBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dQUGo1Fy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_dQUGo1Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3RqNkJmL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_kplz3XFQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5Uh47AzW, 0, m, &cSlice_5Uh47AzW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BfazAu2M_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_5Uh47AzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PypTcEIA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PypTcEIA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_EWJ64dCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PypTcEIA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_PypTcEIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YvR4A3K8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_qflEAIa8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_V79YuEvs, 0, m, &cSlice_V79YuEvs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TVXyOI8M_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_V79YuEvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TzScySUq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TzScySUq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_whtEv2f4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TzScySUq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_TzScySUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RR5NhbUP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_TVXyOI8M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4Y5R3uop, 0, m, &cSlice_4Y5R3uop_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aIUt2v96_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_4Y5R3uop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Lzaq7oUv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Lzaq7oUv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_LmS6HJtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Lzaq7oUv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Lzaq7oUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hceLZNPR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_ufNJ0wIT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eZVWrszd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eZVWrszd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_n46i99q5, 1, m, &cDelay_n46i99q5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kJazMotx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_n46i99q5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n46i99q5, m);
  cMsg_ds6ov9r1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_eZVWrszd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_n46i99q5, 0, m, &cDelay_n46i99q5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kJazMotx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_n46i99q5, 0, m, &cDelay_n46i99q5_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_6XxrHDIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N6h8Kbai, HV_BINOP_SUBTRACT, 0, m, &cBinop_N6h8Kbai_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_tIlzGX36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8BsD6MAh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Cm4tABHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8BsD6MAh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_QG5mvrzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6XxrHDIZ, 0, m, &cVar_6XxrHDIZ_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_mQMk3SNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tvdlFRr6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yBIi932S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vi6ShwNP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_N6h8Kbai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JkWGsCWK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_JkWGsCWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LUeGlAKB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LUeGlAKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qh9EA6PB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_MjTezGix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NGakSjXE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bUTuwEwp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bUTuwEwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aRGGNmSe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_NGakSjXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tIlzGX36, 1, m, &cIf_tIlzGX36_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_lDScZvR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cm4tABHl, 1, m, &cIf_Cm4tABHl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aRGGNmSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tIlzGX36, 0, m, &cIf_tIlzGX36_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qh9EA6PB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Cm4tABHl, 0, m, &cIf_Cm4tABHl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Vi6ShwNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6XxrHDIZ, 0, m, &cVar_6XxrHDIZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tvdlFRr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_yBIi932S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N6h8Kbai, HV_BINOP_SUBTRACT, 1, m, &cBinop_N6h8Kbai_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8BsD6MAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BBIR43x5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_aIUt2v96_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_o2KGk3Cv, 0, m, &cSlice_o2KGk3Cv_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_o2KGk3Cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pVbSWgqo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pVbSWgqo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_Ji84dnK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pVbSWgqo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_pVbSWgqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AI4GO4ps_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RU2VjeTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GoZbNMJ9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_bNLH8lkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sTS0py63, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_BNhtZVhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VQv5cgWJ, 0, m, &cVar_VQv5cgWJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Lmj7par9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aN5qreTy, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_o0hVVu2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ufNJ0wIT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_ehC08mEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GtMeQMKi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ds6ov9r1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5eQi4M1k, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_GtMeQMKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5eQi4M1k, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_IaRxUE2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_gWEr9QT0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gWEr9QT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S0nRTQA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_S0nRTQA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GqVG9D41, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_0AQXxosv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kms1xO7K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_VcxU24Dm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WoxHOfkR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_zkXDLi8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jb3jgnAG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_L24Ils5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_imFruMzG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ozptETRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x3Ag1FCQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Ch1TWavf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_7vspuxi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x3Ag1FCQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Ch1TWavf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_vkvbfDMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KndcCB0t, 0, m, &cVar_KndcCB0t_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1HKYOX1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x3Ag1FCQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Ch1TWavf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ycC3H3d9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x3Ag1FCQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Ch1TWavf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_lXSOxSC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x3Ag1FCQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Ch1TWavf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_8L3UQGwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_vyf6Eq3V, 0, m, &cVar_vyf6Eq3V_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JFwReyyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_za2n6tOw, 0, m, &cVar_za2n6tOw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TYfdimWi, 0, m, &cVar_TYfdimWi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nALJqmjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_vkvbfDMi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_i3naFO1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_YdfZQrKO, 0, m, &cVar_YdfZQrKO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Kms1xO7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_x3Ag1FCQ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Ch1TWavf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_XxsHUCpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_0AQXxosv, 0, m, &cVar_0AQXxosv_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_imFruMzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_b7fDYoGM_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_VAkYco5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BQ9Mp3Q1, 0, m, &cVar_BQ9Mp3Q1_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_R3lF334e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_vkvbfDMi_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_TpluaabN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vyf6Eq3V, 0, m, &cVar_vyf6Eq3V_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Qz9ONBAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RR3ZZy28, 0, m, &cVar_RR3ZZy28_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iraNY5GX, 0, m, &cVar_iraNY5GX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yNrXpt6w, 0, m, &cVar_yNrXpt6w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NgdKis1Y, 0, m, &cVar_NgdKis1Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vshwG1zO, 0, m, &cVar_vshwG1zO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qQj9RAzh, 0, m, &cVar_qQj9RAzh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wgxqY0Oi, 0, m, &cVar_wgxqY0Oi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qjfYXgBt, 0, m, &cVar_qjfYXgBt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EWJ64dCM, 0, m, &cVar_EWJ64dCM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_whtEv2f4, 0, m, &cVar_whtEv2f4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LmS6HJtL, 0, m, &cVar_LmS6HJtL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ji84dnK9, 0, m, &cVar_Ji84dnK9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_meNqCyNs_sendMessage);
  cMsg_i3naFO1l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_76LbTzAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YdfZQrKO, 0, m, &cVar_YdfZQrKO_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_P9kdSzWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_za2n6tOw, 0, m, &cVar_za2n6tOw_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_eZYkjVQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TYfdimWi, 0, m, &cVar_TYfdimWi_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_NNyPxXLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1dB2M1Uh, 0, m, &cVar_1dB2M1Uh_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_U5AgkAej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kdpTA1D1, 0, m, &cVar_kdpTA1D1_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_rFFhUGX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_nvfyTidR_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_x3jgsdOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_30wxPjYo_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NNHWLFUL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KcEvydpn_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Z4Y61TKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l5pT8I8K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_61qBF6gb_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_8ctiBTYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZJSMTNZb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_2E6pJqwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EIbY1376, 0, m, &cVar_EIbY1376_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_RR5NhbUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o5ECzs93, 0, m, &cVar_o5ECzs93_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_YvR4A3K8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_BNhtZVhb_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_3RqNkJmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MeOAr7MB_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ehC08mEH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o0hVVu2U_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_hceLZNPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MjTezGix_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lDScZvR0_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_AI4GO4ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IaRxUE2K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_Zlk2IyTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0AQXxosv, 0, m, &cVar_0AQXxosv_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_BcfKhW5K, VIf(I0));
    __hv_varread_f(&sVarf_KckxTEJn, VOf(Bf0));
    __hv_varread_f(&sVarf_mZWCLdY9, VOf(Bf1));
    __hv_varread_f(&sVarf_CM0EtZcw, VOf(Bf2));
    __hv_varread_f(&sVarf_GDhJSDgA, VOf(Bf3));
    __hv_varread_f(&sVarf_aIMpox5S, VOf(Bf4));
    __hv_varread_f(&sVarf_2T3Ua5Zw, VOf(Bf5));
    __hv_varread_f(&sVarf_WuABKvPf, VOf(Bf6));
    __hv_varwrite_f(&sVarf_SSgZtIWg, VIf(I0));
    __hv_varread_f(&sVarf_fX9qyFrD, VOf(Bf7));
    __hv_line_f(&sLine_zeeqNJPT, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_0NT2wX46, VOf(Bf9));
    __hv_line_f(&sLine_GnUEgPVV, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_hovVEQrb, VOf(Bf8));
    __hv_line_f(&sLine_QJ933Gfb, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_GDhJSDgA, VIf(Bf11));
    __hv_varread_f(&sVarf_SSgZtIWg, VOf(Bf11));
    __hv_line_f(&sLine_MiMYezHw, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_nmhDBwHH, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_4LRIWGRj, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_aIMpox5S, VIf(Bf10));
    __hv_line_f(&sLine_NcLEsPMp, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_hXpgz07j, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_sFgwHGbm, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_2T3Ua5Zw, VIf(Bf10));
    __hv_line_f(&sLine_RTelv2dT, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_VCQD0ZuR, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_UuhYPyoC, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_WuABKvPf, VIf(Bf10));
    __hv_varwrite_f(&sVarf_fX9qyFrD, VIf(Bf0));
    __hv_varwrite_f(&sVarf_0NT2wX46, VIf(Bf1));
    __hv_varwrite_f(&sVarf_hovVEQrb, VIf(Bf2));
    sEnv_process(this, &sEnv_VLW2yjeq, VIf(Bf3), &sEnv_VLW2yjeq_sendMessage);
    sEnv_process(this, &sEnv_GBxkNI7z, VIf(I0), &sEnv_GBxkNI7z_sendMessage);
    __hv_line_f(&sLine_Y6Mk3UKB, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_8GWuojOz, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_gQYA2KRZ, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_7uUGcLP5, VOf(Bf3));
    __hv_line_f(&sLine_By1HqzXr, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_KckxTEJn, VIf(Bf0));
    __hv_varwrite_f(&sVarf_7uUGcLP5, VIf(Bf4));
    __hv_varwrite_f(&sVarf_2dfvGF0a, VIf(Bf5));
    __hv_varwrite_f(&sVarf_hnOOs6rQ, VIf(Bf6));
    __hv_varread_f(&sVarf_hnOOs6rQ, VOf(Bf6));
    __hv_line_f(&sLine_GFCNc8Om, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_CM0EtZcw, VIf(Bf4));
    __hv_varread_f(&sVarf_2dfvGF0a, VOf(Bf4));
    __hv_line_f(&sLine_ymDErHOy, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_mZWCLdY9, VIf(Bf4));
    __hv_varwrite_f(&sVarf_QKvnGwVR, VIf(Bf2));
    __hv_varwrite_f(&sVarf_xJj6WuXl, VIf(I1));
    __hv_varread_f(&sVarf_xZLWbpzs, VOf(Bf2));
    __hv_varread_f(&sVarf_fFRYVlaK, VOf(Bf4));
    __hv_varread_f(&sVarf_kDpZ2dpJ, VOf(Bf0));
    __hv_varread_f(&sVarf_V7tRqKn9, VOf(Bf5));
    __hv_varread_f(&sVarf_tSmmZGt5, VOf(Bf3));
    __hv_varread_f(&sVarf_K8lwmSh7, VOf(Bf6));
    __hv_varread_f(&sVarf_IQtB19Af, VOf(Bf1));
    __hv_varwrite_f(&sVarf_zm7kKFF2, VIf(I1));
    __hv_varread_f(&sVarf_dU5hNAMY, VOf(Bf10));
    __hv_line_f(&sLine_3vKVOhdl, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_egTAL1oX, VOf(Bf7));
    __hv_line_f(&sLine_e6yjT1tL, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_PB01EMCY, VOf(Bf11));
    __hv_line_f(&sLine_Wq1zFKvK, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_V7tRqKn9, VIf(Bf12));
    __hv_varread_f(&sVarf_zm7kKFF2, VOf(Bf12));
    __hv_line_f(&sLine_vq2svqac, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_sJEu12YS, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_85SDR9B0, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_tSmmZGt5, VIf(Bf9));
    __hv_line_f(&sLine_cl2XeX2q, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_mwTFGVsE, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_FYWjs0Rl, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_K8lwmSh7, VIf(Bf9));
    __hv_line_f(&sLine_K5J18qLv, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_yv9GGVQq, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_DorU08PQ, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_IQtB19Af, VIf(Bf9));
    __hv_varwrite_f(&sVarf_dU5hNAMY, VIf(Bf2));
    __hv_varwrite_f(&sVarf_egTAL1oX, VIf(Bf4));
    __hv_varwrite_f(&sVarf_PB01EMCY, VIf(Bf0));
    sEnv_process(this, &sEnv_QG5mvrzE, VIf(Bf5), &sEnv_QG5mvrzE_sendMessage);
    sEnv_process(this, &sEnv_mQMk3SNJ, VIf(I1), &sEnv_mQMk3SNJ_sendMessage);
    __hv_line_f(&sLine_BBIR43x5, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_5eQi4M1k, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_GqVG9D41, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_MbegGErH, VOf(Bf5));
    __hv_line_f(&sLine_sTS0py63, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_xZLWbpzs, VIf(Bf2));
    __hv_varwrite_f(&sVarf_MbegGErH, VIf(Bf3));
    __hv_varwrite_f(&sVarf_PszEygMf, VIf(Bf6));
    __hv_varwrite_f(&sVarf_eUV16DNQ, VIf(Bf1));
    __hv_varread_f(&sVarf_eUV16DNQ, VOf(Bf1));
    __hv_line_f(&sLine_aN5qreTy, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_kDpZ2dpJ, VIf(Bf3));
    __hv_varread_f(&sVarf_PszEygMf, VOf(Bf3));
    __hv_line_f(&sLine_GoZbNMJ9, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_fFRYVlaK, VIf(Bf3));
    __hv_varwrite_f(&sVarf_RBpwfTZi, VIf(Bf0));
    __hv_varread_f(&sVarf_BcfKhW5K, VOf(Bf0));
    __hv_line_f(&sLine_jb3jgnAG, VOf(Bf3));
    __hv_varread_f(&sVarf_QKvnGwVR, VOf(Bf2));
    __hv_line_f(&sLine_WoxHOfkR, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_xJj6WuXl, VOf(Bf2));
    __hv_varread_f(&sVarf_RBpwfTZi, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
